<?php

namespace Modules\St\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\St\Entities\Module;
use Modules\St\Entities\RoleModule;
use Modules\St\Entities\UserRoleModule;

class ModuleController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    public function index()
    {
        return view('st::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {
        return view('st::create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
        return view('st::show');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {
        return view('st::edit');
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Renderable
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function destroy($id)
    {
        //
    }



    public function allModules($id)
    {
        try {
            $modules =  Module::all();
            $module_array = [];
            foreach ($modules as $module) {
                $role_module = RoleModule::where('role_id', '=', $id)->where('module_id', '=', $module->id)->first();
                if ($role_module) {
                    array_push($module_array, ["id" => $module->id, "name" => $module->module_name, "assigned" => true]);
                } else {
                    array_push($module_array, ["id" => $module->id, "name" => $module->module_name, "assigned" => false]);
                }
            }
            $responseBody = $this->responseBody(true, "Module", "allModules", $module_array);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "Module", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function allowModule(Request $request)
    {

        try {
            $userRole_Module = new RoleModule();
            $userRole_Module->role_id = $request->get('role_id');
            $userRole_Module->module_id = $request->get('module_id');
            $save = $userRole_Module->save();
            if ($save) {
                $responseBody = $this->responseBody(true, "UserRoleModule", "saved", null);
            } else {
                $responseBody = $this->responseBody(false, "UserRoleModule", "saved", $save);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "UserRoleModule", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    public function removeAllowedModule(Request $request)
    {
        try {
            $user_role_id = $request->get('role_id');
            $module_id = $request->get('module_id');

            $status = DB::table('role_modules')->where([['role_id', '=', $user_role_id], ['module_id', '=', $module_id]])->delete();
            $responseBody = $this->responseBody(true, "User", "deleted", $status);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "User", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }




    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
